@@ -18,6 +18,7 @@ from nonebot.params import CommandArg, Arg
 from nonebot.log import logger
 from nonebot.permission import SUPERUSER
 
+from pathlib import Path
 import math
 import time
 import asyncio
@@ -25,6 +26,7 @@ import random
 
 import shutil
 import os
+import io
 
 from .utils import is_number, get_message_at, text_to_png
 from .data_source import (
@@ -34,15 +36,17 @@ from .data_source import (
     max_bet_gold,
     race_bet_gold,
     russian_path,
-    cache
+    linechart_cache,
+    candlestick_cache
     )
-from .data_source import constant_props
 from .utils import company_info_Splicing
 
 from .start import *
 from .race_group import race_group
 from .setting import  *
 
+from nonebot_plugin_imageutils import text2image
+
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 
 data_file = russian_path / "data" / "russian"
@@ -669,24 +673,20 @@ async def _(bot: Bot, event: MessageEvent,arg: Message = CommandArg()):
     await gacha.finish(msg, at_sender=True)
 
 # 我的
-my_props = on_command("我的道具", aliases={"我的仓库"}, permission=GROUP, priority=5, block=True)
+my_props = on_command("我的道具", aliases={"我的仓库"}, priority=5, block=True)
 
 @my_props.handle()
-async def _(event: GroupMessageEvent):
-    user = russian_manager.get_user_data(event)
-    props = user["props"]
-    props_info = '\n'
-    for x in props.keys():
-        if props[x] != 0:
-            if x in constant_props:
-                props_info += f'『{x}』 {props[x]}个\n'
-            else:
-                props_info += f'『{x}』 {props[x]}天\n'
-
-    props_info = props_info[:-1]
-    if not props_info:
-        props_info = "你的仓库空空如也..."
-    await my_props.finish(props_info,at_sender=True)
+async def _(event: MessageEvent):
+    msg = russian_manager.my_props(event)
+    if msg == 0:
+        msg = "私聊未关联账户，请先关联群内账户。"
+    elif msg == 1:
+        msg = "您的仓库空空如也。"
+    else:
+        output = io.BytesIO()
+        text2image(msg).save(output, format="png")
+        msg = MessageSegment.image(output)
+    await my_props.finish(msg)
 
 my_gold = on_command("我的金币", priority=5, block=True)
 
@@ -765,8 +765,11 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         msg = msg.split()
         if len(msg) == 1:
             msg = msg[0]
-            msg = market_manager.public(event,msg)
-            await Market_public.finish(msg)
+            if is_number(msg):
+                await Market_public.finish("错误：公司名称不可以是数字。")
+            else:
+                msg = market_manager.public(event,msg)
+                await Market_public.finish(msg)
         else:
             await Market_public.finish(f"错误：公司名称格式错误\n{str(msg)}")
     else:
@@ -855,48 +858,36 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
                     await Market_sell.finish()
 
 # 市场信息
-Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
+Market_info = on_command("市场信息",aliases={"查看市场","市场行情","市场走势"}, priority=5, block=True)
 
 @Market_info.handle()
 async def _(bot:Bot, event: MessageEvent,arg: Message = CommandArg()):
-    company_name = arg.extract_plain_text().strip()
-    if company_name:
-        company_name = company_name.split()
-        company_name = company_name[0]
+    cmd = event.raw_message
+    if "市场行情" in cmd or "市场走势" in cmd:
+        await Market_info.send("正在生成走势图。")
+        company_name = "pro"
     else:
-        company_name == ""
+        company_name = arg.extract_plain_text().strip()
+        if company_name:
+            company_name = company_name.split()
+            company_name = company_name[0]
+        else:
+            company_name == ""
 
-    msg = market_manager.Market_info(event,company_name)
+    msg = await market_manager.Market_info(event,company_name)
 
     if type(msg) == list:
-        if isinstance(event, GroupMessageEvent):
-            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
+        if len(msg) == 1:
+            await Market_info.finish(msg[0]["data"]["content"])
         else:
-            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
+            if isinstance(event, GroupMessageEvent):
+                await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
+            else:
+                await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
         await Market_info.finish()
     else:
         await Market_info.finish(msg)
 
-# 市场走势
-Market_ohlc = on_command("市场行情",aliases={"市场走势"}, priority=5, block=True)
-
-@Market_ohlc.handle()
-async def _(bot:Bot, event: MessageEvent):
-    if market_manager.ohlc_temp[1] <= 6:
-        msg = market_manager.ohlc_temp[0]
-    else:
-        await Market_ohlc.send("正在生成走势图...")
-        msg = await market_manager.ohlc(event)
-
-    if type(msg) == list:
-        if isinstance(event, GroupMessageEvent):
-            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
-        else:
-            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
-        await Market_ohlc.finish()
-    else:
-        await Market_ohlc.finish(msg)
-
 # 公司信息
 company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
 
@@ -908,10 +899,9 @@ async def _(event: MessageEvent,arg: Message = CommandArg()):
         company_name = company_name[0]
         msg = market_manager.company_info(company_name)
         if msg:
-            if os.path.exists(cache / "ohlc.json"):
-                with open(cache / "ohlc.json", "r", encoding="utf8") as f:
-                    ohlc = json.load(f)
-                output = company_info_Splicing(msg ,ohlc[company_name])
+            ohlc = [Path(linechart_cache / company_name), Path(candlestick_cache / company_name)]
+            if os.path.exists(ohlc[0]) and os.path.exists(ohlc[1]):
+                output = company_info_Splicing(msg ,ohlc)
             else:
                 output = text_to_png(msg)
             await company_info.finish(MessageSegment.image(output))
@@ -957,22 +947,13 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         msg = market_manager.intergroup_transfer(event,company_name,gold)
         await intergroup_transfer.finish(msg, at_sender=True)
 
-# 股票回收
-repurchase = on_command("股票回收",aliases={"回收股票"} ,rule = to_me() , permission = SUPERUSER, priority=5, block = True)
-
-@repurchase.handle()
-async def _(bot:Bot):
-    await repurchase.send("正在启动回收程序。")
-    msg = await market_manager.repurchase(bot)
-    await repurchase.finish(msg)
-
-# 公司退市
-delist = on_command("公司退市",aliases={"清理市场", "市场清理"} ,rule = to_me() , permission = SUPERUSER, priority=5, block = True)
+# 清理无效账户
+delist = on_command("清理无效账户", rule = to_me() , permission = SUPERUSER, priority=5, block = True)
 
 @delist.handle()
-async def _(bot:Bot):
-    await delist.send("正在启动退市程序。")
-    msg = await market_manager.delist(bot)
+async def _(bot:Bot, event:MessageEvent):
+    await delist.send("正在启动清理程序。")
+    msg = await market_manager.delist(bot,event)
     await delist.finish(msg)
 
 # 刷新每日签到和每日补贴
